@@ -140,7 +140,6 @@ void Office2007Extractor::extract(ExtractionResult* result)
 
         QDomElement docElem = appDoc.documentElement();
 
-        // According to the ontologies only Documents can have a wordCount and pageCount
         const QString mimeType = result->inputMimetype();
         if (mimeType == QLatin1String("application/vnd.openxmlformats-officedocument.wordprocessingml.document")) {
             QDomElement elem = docElem.firstChildElement(QStringLiteral("Pages"));
@@ -160,6 +159,15 @@ void Office2007Extractor::extract(ExtractionResult* result)
                     result->add(Property::WordCount, wordCount);
                 }
             }
+
+            elem = docElem.firstChildElement(QStringLiteral("Lines"));
+            if (!elem.isNull()) {
+                bool ok = false;
+                int lineCount = elem.text().toInt(&ok);
+                if (ok) {
+                    result->add(Property::LineCount, lineCount);
+                }
+            }
         }
 
         QDomElement elem = docElem.firstChildElement(QStringLiteral("Application"));
@@ -179,8 +187,9 @@ void Office2007Extractor::extract(ExtractionResult* result)
     if (rootEntries.contains(QStringLiteral("word"))) {
         result->addType(Type::Document);
 
-        if (!extractPlainText)
+        if (!extractPlainText) {
             return;
+        }
 
         const KArchiveEntry* wordEntry = rootDir->entry(QStringLiteral("word"));
         if (!wordEntry->isDirectory()) {
@@ -205,8 +214,9 @@ void Office2007Extractor::extract(ExtractionResult* result)
         result->addType(Type::Document);
         result->addType(Type::Spreadsheet);
 
-        if (!extractPlainText)
+        if (!extractPlainText) {
             return;
+        }
 
         const KArchiveEntry* xlEntry = rootDir->entry(QStringLiteral("xl"));
         if (!xlEntry->isDirectory()) {
@@ -214,16 +224,24 @@ void Office2007Extractor::extract(ExtractionResult* result)
             return;
         }
 
-        const KArchiveDirectory* xlDirectory = dynamic_cast<const KArchiveDirectory*>(xlEntry);
-        extractTextFromFiles(xlDirectory, result);
+        const auto xlDirectory = dynamic_cast<const KArchiveDirectory*>(xlEntry);
+        // TODO: Read the sheets from worksheets/*.xml, and dereference all cells
+        // values in order
+        const KArchiveFile* file = xlDirectory->file(QStringLiteral("sharedStrings.xml"));
+        if (!file) {
+            return;
+        }
+        std::unique_ptr<QIODevice> contentIODevice{file->createDevice()};
+        extractTextWithTag(contentIODevice.get(), QStringLiteral("t"), result);
     }
 
     else if (rootEntries.contains(QStringLiteral("ppt"))) {
         result->addType(Type::Document);
         result->addType(Type::Presentation);
 
-        if (!extractPlainText)
+        if (!extractPlainText) {
             return;
+        }
 
         const KArchiveEntry* pptEntry = rootDir->entry(QStringLiteral("ppt"));
         if (!pptEntry->isDirectory()) {
@@ -231,45 +249,24 @@ void Office2007Extractor::extract(ExtractionResult* result)
             return;
         }
 
-        const KArchiveDirectory* pptDirectory = dynamic_cast<const KArchiveDirectory*>(pptEntry);
-        extractTextFromFiles(pptDirectory, result);
-    }
-}
-
-void Office2007Extractor::extractAllText(QIODevice* device, ExtractionResult* result)
-{
-    QXmlStreamReader xml(device);
-
-    while (!xml.atEnd()) {
-        xml.readNext();
-        if (xml.isCharacters()) {
-            QString str = xml.text().toString();
-            result->append(str);
+        const auto pptDirectory = dynamic_cast<const KArchiveDirectory*>(pptEntry);
+        const auto slidesEntry = pptDirectory->entry(QStringLiteral("slides"));
+        if (!slidesEntry || !slidesEntry->isDirectory()) {
+            return;
         }
 
-        if (xml.isEndDocument() || xml.hasError())
-            break;
-    }
-}
-
-void Office2007Extractor::extractTextFromFiles(const KArchiveDirectory* archiveDir, ExtractionResult* result)
-{
-    const QStringList entries = archiveDir->entries();
-    for (const QString & entryName : entries) {
-        const KArchiveEntry* entry = archiveDir->entry(entryName);
-        if (!entry) {
-            continue;
-        }
-        if (entry->isDirectory()) {
-            const KArchiveDirectory* subDir = dynamic_cast<const KArchiveDirectory*>(entry);
-            extractTextFromFiles(subDir, result);
-            continue;
-        }
-
-        if (entry->isFile() && entryName.endsWith(QLatin1String(".xml"))) {
-            const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
+        const auto slidesDirectory = dynamic_cast<const KArchiveDirectory*>(slidesEntry);
+        QStringList entries = slidesDirectory->entries();
+        // TODO: Read the actual order from presentation.xml, and follow the
+        // references in ppt/_rels/presentation.xml.rel
+        std::sort(entries.begin(), entries.end());
+        for (const QString & entryName : std::as_const(entries)) {
+            const KArchiveFile* file = slidesDirectory->file(entryName);
+            if (!file) {
+                continue;
+            }
             std::unique_ptr<QIODevice> contentIODevice{file->createDevice()};
-            extractAllText(contentIODevice.get() , result);
+            extractTextWithTag(contentIODevice.get(), QStringLiteral("a:t"), result);
         }
     }
 }
@@ -288,7 +285,10 @@ void Office2007Extractor::extractTextWithTag(QIODevice* device, const QString& t
             }
         }
 
-        if (xml.isEndDocument() || xml.hasError())
+        if (xml.isEndDocument() || xml.hasError()) {
             break;
+        }
     }
 }
+
+#include "moc_office2007extractor.cpp"
