@@ -1,27 +1,16 @@
 /*
     This file is part of a KMetaData File Extractor
-    Copyright (C) 2013  Denis Steckelmacher <steckdenis@yahoo.fr>
+    SPDX-FileCopyrightText: 2013 Denis Steckelmacher <steckdenis@yahoo.fr>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "officeextractor.h"
+#include "kfilemetadata_debug.h"
 
+#include <QRegularExpression>
 #include <QStandardPaths>
 
-#include <QFile>
 #include <QProcess>
 
 using namespace KFileMetaData;
@@ -70,7 +59,7 @@ void OfficeExtractor::extract(ExtractionResult* result)
         // Now that we have the plain text content, count words, lines and characters
         // (original code from plaintextextractor.cpp, authored by Vishesh Handa)
         int lines = contents.count(QLatin1Char('\n'));
-        int words = contents.count(QRegExp(QStringLiteral("\\b\\w+\\b")));
+        int words = contents.count(QRegularExpression(QStringLiteral("\\b\\w+\\b"), QRegularExpression::UseUnicodePropertiesOption));
 
         result->add(Property::WordCount, words);
         result->add(Property::LineCount, lines);
@@ -89,8 +78,9 @@ void OfficeExtractor::extract(ExtractionResult* result)
         contents = textFromFile(fileUrl, m_catppt, args);
     }
 
-    if (contents.isEmpty())
+    if (contents.isEmpty()) {
         return;
+    }
 
     result->append(contents);
 
@@ -99,17 +89,26 @@ void OfficeExtractor::extract(ExtractionResult* result)
 
 QString OfficeExtractor::textFromFile(const QString& fileUrl, const QString& command, QStringList& arguments)
 {
+    const QString exec = QStandardPaths::findExecutable(command);
+    if (exec.isEmpty()) {
+        qCDebug(KFILEMETADATA_LOG) << "Could not find executable in PATH:" << command;
+        return {};
+    }
+
     arguments << fileUrl;
 
     // Start a process and read its standard output
     QProcess process;
 
     process.setReadChannel(QProcess::StandardOutput);
-    process.start(command, arguments, QIODevice::ReadOnly);
+    process.start(exec, arguments, QIODevice::ReadOnly);
     process.waitForFinished();
 
-    if (process.exitStatus() != QProcess::NormalExit || process.exitCode() != 0)
+    if (process.exitStatus() != QProcess::NormalExit || process.exitCode() != 0) {
         return QString();
-    else
+    } else {
         return QString::fromUtf8(process.readAll());
+    }
 }
+
+#include "moc_officeextractor.cpp"
