@@ -11,6 +11,10 @@
 
 // Taglib includes
 #include <taglib.h>
+#include <modfile.h>
+#include <s3mfile.h>
+#include <xmfile.h>
+#include <itfile.h>
 #include <tag.h>
 #include <tfilestream.h>
 #include <tpropertymap.h>
@@ -35,6 +39,7 @@
 #include <id3v2tag.h>
 #include <mp4tag.h>
 #include <popularimeterframe.h>
+#include <attachedpictureframe.h>
 
 using namespace KFileMetaData;
 
@@ -62,6 +67,10 @@ const QStringList supportedMimeTypes = {
     QStringLiteral("audio/x-vorbis+ogg"),
     QStringLiteral("audio/x-wav"),
     QStringLiteral("audio/x-wavpack"),
+    QStringLiteral("audio/x-mod"),
+    QStringLiteral("audio/x-s3m"),
+    QStringLiteral("audio/x-xm"),
+    QStringLiteral("audio/x-it"),
 };
 
 void extractAudioProperties(TagLib::File* file, ExtractionResult* result)
@@ -244,6 +253,9 @@ void readGenericProperties(const TagLib::PropertyMap &savedProperties, Extractio
             result->add(Property::ReplayGainAlbumPeak, replayGainAlbumPeak);
         }
     }
+    if (savedProperties.contains("TRACKERNAME")) {
+        result->add(Property::Generator, TStringToQString(savedProperties["TRACKERNAME"].toString()).trimmed());
+    }
 }
 
 void extractId3Tags(TagLib::ID3v2::Tag* Id3Tags, ExtractionResult* result)
@@ -677,6 +689,30 @@ void TagLibExtractor::extract(ExtractionResult* result)
                 result->addImageData(extractAsfCover(asfTags, imageTypes));
             }
         }
+    } else if (mimeType == QLatin1String("audio/x-mod")) {
+        TagLib::Mod::File file(&stream);
+        if (file.isValid()) {
+            extractAudioProperties(&file, result);
+            readGenericProperties(file.properties(), result);
+        }
+    } else if (mimeType == QLatin1String("audio/x-s3m")) {
+        TagLib::S3M::File file(&stream);
+        if (file.isValid()) {
+            extractAudioProperties(&file, result);
+            readGenericProperties(file.properties(), result);
+        }
+    } else if (mimeType == QLatin1String("audio/x-xm")) {
+        TagLib::XM::File file(&stream);
+        if (file.isValid()) {
+            extractAudioProperties(&file, result);
+            readGenericProperties(file.properties(), result);
+        }
+    } else if (mimeType == QLatin1String("audio/x-it")) {
+        TagLib::IT::File file(&stream);
+        if (file.isValid()) {
+            extractAudioProperties(&file, result);
+            readGenericProperties(file.properties(), result);
+        }
     }
 
     result->addType(Type::Audio);
