@@ -1,24 +1,9 @@
 /*
- * This file is part of the KFileMetaData project
- * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KFileMetaData project
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #ifndef _KFILEMETADATA_PROPERTYINFO_H
 #define _KFILEMETADATA_PROPERTYINFO_H
@@ -30,6 +15,7 @@
 
 namespace KFileMetaData {
 
+class PropertyInfoData;
 /**
  * \class PropertyInfo propertyinfo.h <KFileMetaData/PropertyInfo>
  *
@@ -41,6 +27,7 @@ namespace KFileMetaData {
 class KFILEMETADATA_EXPORT PropertyInfo
 {
 public:
+    PropertyInfo();
     PropertyInfo(Property::Property property);
     PropertyInfo(const PropertyInfo& pi);
     ~PropertyInfo();
@@ -60,6 +47,10 @@ public:
 
     /**
      * A user visible name of the property
+     *
+     * Note: When the displayName for a given property is used repeatedly
+     * the returned value should be cached, as calling this method is
+     * fairly expensive, as the returned name is localized.
      */
     QString displayName() const;
 
@@ -67,7 +58,7 @@ public:
      * The type the value of this property should be.
      * Eg - Property::Height should be an integer
      */
-    QVariant::Type valueType() const;
+    QMetaType::Type valueType() const;
 
     /**
      * Indicates if this property requires indexing or should just be stored.
@@ -85,10 +76,29 @@ public:
      */
     static PropertyInfo fromName(const QString& name);
 
+    /**
+     * Get the names of all valid, supported properties
+     *
+     * Note: Property::Empty is not considered a valid property.
+     *
+     * @since 6.0
+     * @since 5.107
+     */
+    static QStringList allNames();
+
+    /**
+     * Returns the value of the property as a QString with added formatting,
+     * added units if needed, and translated enums.
+     * @since 5.56
+     */
+    QString formatAsDisplayString(const QVariant& value) const;
+
 private:
-    class Private;
-    Private* d;
+    const PropertyInfoData* d;
 };
 
-}
+} // namespace
+Q_DECLARE_METATYPE(KFileMetaData::PropertyInfo)
+
+
 #endif // _KFILEMETADATA_PROPERTYINFO_H
